@@ -1,4 +1,5 @@
 from nonebot import on_command
+from nonebot.adapters.cqhttp.message import MessageSegment
 from nonebot.rule import to_me
 from nonebot.typing import T_State
 from nonebot.adapters.cqhttp import Bot, Event
@@ -6,18 +7,20 @@ import ujson as json
 import os
 
 from .r6s_data import *
-from .r6s_ground import get_data as get_data_from_ground
+from .net import get_data_from_r6scn
+from .image import *
+from .player import new_player_from_r6scn
 
 
-r6s = on_command("r6s", aliases={"彩六", "彩虹六号", "r6", "R6"}, rule=to_me())
-r6s_pro = on_command("r6spro", aliases={"r6pro", "R6pro"}, rule=to_me())
-r6s_ops = on_command("r6sops", aliases={"r6ops", "R6ops"}, rule=to_me())
-r6s_plays = on_command("r6sp", aliases={"r6p", "R6p"}, rule=to_me())
-r6s_set = on_command("r6sset", aliases={"r6set", "R6set"}, rule=to_me())
+r6s = on_command("r6s", aliases={"彩六", "彩虹六号", "r6", "R6"}, rule=to_me(), priority=5, block=True)
+r6s_pro = on_command("r6spro", aliases={"r6pro", "R6pro"}, rule=to_me(), priority=5, block=True)
+r6s_ops = on_command("r6sops", aliases={"r6ops", "R6ops"}, rule=to_me(), priority=5, block=True)
+r6s_plays = on_command("r6sp", aliases={"r6p", "R6p"}, rule=to_me(), priority=5, block=True)
+r6s_set = on_command("r6sset", aliases={"r6set", "R6set"}, rule=to_me(), priority=5, block=True)
 
 
 _cachepath = os.path.join("cache", "r6s.json")
-ground_can_do = (base, pro) # ground数据源乱码过多，干员和近期战绩还在努力解码中···
+ground_can_do = (base, pro)  # ground数据源乱码过多，干员和近期战绩还在努力解码中···
 
 
 if not os.path.exists("cache"):
@@ -57,6 +60,16 @@ async def handler(matcher, state: T_State, func):
     await matcher.finish(func(data))
 
 
+async def new_handler(matcher, state: T_State, func):
+    username = state["username"]
+    data = await get_data_from_r6scn(username)
+    if data == "Not Found":
+        await matcher.finish("未找到干员『%s』" % username)
+    player = new_player_from_r6scn(data)
+    img_b64 = encode_b64(await func(player))
+    await matcher.finish(MessageSegment.image(file=f"base64://{img_b64}"))
+
+
 @r6s_set.handle()
 async def r6s_set_handler(bot: Bot, event: Event):
     args = str(event.get_message()).strip()
@@ -76,7 +89,8 @@ async def r6s_handler(bot: Bot, event: Event, state: T_State):
 
 @r6s.got("username", prompt="请输入查询的角色昵称")
 async def r6s_goter(bot: Bot, event: Event, state: T_State):
-    await handler(r6s, state, base)
+    # await handler(r6s, state, base)
+    await new_handler(r6s, state, base_image)
 
 
 @r6s_pro.handle()
@@ -86,7 +100,8 @@ async def r6s_pro_handler(bot: Bot, event: Event, state: T_State):
 
 @r6s_pro.got("username", prompt="请输入查询的角色昵称")
 async def r6s_pro_goter(bot: Bot, event: Event, state: T_State):
-    await handler(r6s, state, pro)
+    # await handler(r6s, state, pro)
+    await new_handler(r6s_pro, state, detail_image)
 
 
 @r6s_ops.handle()
@@ -96,7 +111,8 @@ async def r6s_ops_handler(bot: Bot, event: Event, state: T_State):
 
 @r6s_ops.got("username", prompt="请输入查询的角色昵称")
 async def r6s_ops_goter(bot: Bot, event: Event, state: T_State):
-    await handler(r6s, state, operators)
+    # await handler(r6s, state, operators)
+    await new_handler(r6s_ops, state, operators_img)
 
 
 @r6s_plays.handle()
@@ -106,4 +122,5 @@ async def r6s_plays_handler(bot: Bot, event: Event, state: T_State):
 
 @r6s_plays.got("username", prompt="请输入查询的角色昵称")
 async def r6s_plays_goter(bot: Bot, event: Event, state: T_State):
-    await handler(r6s, state, plays)
+    # await handler(r6s, state, plays)
+    await new_handler(r6s_plays, state, plays_image)
